# [Zope-tests] FAILED : winbot / ztk_dev py_270_win32

buildbot at winbot.zope.org buildbot at winbot.zope.org
Wed Feb 2 15:37:02 EST 2011

- Previous message: [Zope-tests] OK : winbot / ztk_dev py_265_win64
- Next message: [Zope-tests] OK : winbot / ztk_dev py_270_win64
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

    FAILED : winbot / ztk_dev py_270_win32
    Build: http://winbot.zope.org/builders/ztk_dev%20py_270_win32/builds/139

    Build Reason: The Nightly scheduler named 'ztk_dev py_270_win32_nightly' triggered this build

    Build Source Stamp: HEAD

    Blamelist:

    Buildbot: http://winbot.zope.org/

- Previous message: [Zope-tests] OK : winbot / ztk_dev py_265_win64
- Next message: [Zope-tests] OK : winbot / ztk_dev py_270_win64
- Messages sorted by: [ date ] [ thread ] [ subject ] [ author ]

More information about the Zope-tests mailing list